@@ -16,6 +16,9 @@
 # along with Biggus. If not, see <http://www.gnu.org/licenses/>.
 """Integration tests for maths operations."""
 
+from __future__ import absolute_import, division, print_function
+from six.moves import (filter, input, map, range, zip)  # noqa
+
 import numpy as np
 import numpy.ma as ma
 import unittest
