@@ -16,6 +16,9 @@
 # along with Biggus. If not, see <http://www.gnu.org/licenses/>.
 """Unit tests for `biggus._init._ArrayAdapter`."""
 
+from __future__ import absolute_import, division, print_function
+from six.moves import (filter, input, map, range, zip)  # noqa
+
 import unittest
 
 from biggus._init import _ArrayAdapter
